## ${app_name}

Version ${version}

Git Hash: ${hash}

An application to load, export, and visualise profiles recorded
with SnowMicroPen©, a high resolution snow penetration probe
for scientific applications developed at SLF.

This project is licensed under GNU GPL. Its source code is hosted
on GitHub and the documentation can be studied on Read the Docs.

Please send feedback and suggestions to snowmicropen@slf.ch.

Copyright 2018, WSL Institute for Snow and Avalanche Research SLF.

### Contributors

Sascha Grimm, Marcel Schoch, Thiemo Theile,
Henning Löwe, Martin Schneebeli, Michael Reisecker

### Acknowledgements

Developing this application within reasonable time was
possible due to the use of some great software:

The beloved language of Python,
the beautiful Qt toolkit and the python binding pyqt,
the awesome python packages matploblib, numpy, scipy, pandas and pytz.

Icons by Icons8.